/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2016 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.extension.data;

import static org.conqat.lib.commons.collections.CollectionUtils.asUnmodifiable;

import java.util.LinkedList;
import java.util.List;

/**
 * Data class for defining tutorials.
 * 
 * @author hoelzl
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating RED Hash:
 */
public final class TutorialDefinition {
	/** The title of the tutorial. */
	private final String title;
	/** The contained tutorial steps. */
	private final List<TutorialStep> steps = new LinkedList<TutorialStep>();

	/** Constructor. */
	public TutorialDefinition(String title, TutorialStep initialStep) {
		this.title = title;
		addStep(initialStep);
	}

	/** Returns tutorial steps. MUST NOT return <code>null</code> or an empty list. */
	public List<TutorialStep> getSteps() {
		return asUnmodifiable(steps);
	}

	/** Adds the given tutorial step to the list of steps. */
	public void addStep(TutorialStep step) {
		steps.add(step);
	}

	/** Returns the title of the tutorial. */
	public String getTitle() {
		return title;
	}
}
